use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Aas
Adam
Alders
Alex
Base
Berners
Bonaccorso
Branislav
Brendan
Byrd
Ceccarelli
Chae
Chase
Costa
David
Deguest
Dick
Dorian
Dubois
Escape
Etheridge
FAT
Fiegehenn
Fredric
Förtsch
Gianni
Gisle
Graham
Herzog
Heuristic
Honma
Håkon
Hægland
IDNA
IRI
ISBNs
Ishigaki
Jacques
James
Jan
Joenio
John
Julien
Kaitlyn
Kaji
Kapranoff
Karen
Karr
Kenichi
Kent
Kereliuk
Knop
Koster
Lawrence
Mac
Mark
Martijn
Masahiro
Masinter
Matt
Matthew
Michael
Miller
Miyagawa
OIDs
OS2
Olaf
OpenLDAP
Parkhurst
Perl
Perlbotics
Peter
Piotr
Punycode
QNX
QueryParam
Rabbitson
Raspass
Rezic
Roszatycki
Ryan
Salvatore
Schmidt
Schwern
Sebastian
Shoichi
Skyttä
Slaven
Split
Stosberg
TCP
TLS
Tatsuhiko
Taylor
Torsten
UDP
UNC
URI
URL
Unix
Ville
Whitener
Willing
Win32
WithBase
Zahradník
_foreign
_generic
_idna
_ldap
_login
_punycode
_query
_segment
_server
_userpass
adam
brainbuz
brian
capoeirab
carnil
data
davewood
ddick
dorian
ether
etype
evalue
file
foy
ftp
gerard
gianni
gisle
gopher
haarg
hakon
happy
hiratara
http
https
icap
icaps
isbn
ishigaki
jack
jand
joenio
john
jraspass
kapranoff
kentfredric
ldap
ldapi
ldaps
lib
lowercasing
mailto
mark
matthewlawrence
miyagawa
mms
mschae
news
nntp
nntps
oid
olaf
perlbotix
piotr
pop
relativize
ribasushi
rlogin
rsync
rtsp
rtspu
ryker
schwern
sewi
sftp
simbabque
sip
sips
skaji
slaven
snews
ssh
symkat
telnet
tn3270
torsten
unicode
uppercasing
urn
ville
xn
